#include <qtabdialog.h>
#include <qlabel.h>

class Sheet : public QTabDialog
{
    Q_OBJECT

public:
    Sheet( QWidget *parent, const char *name, bool big_info, bool has_dual, bool has_gamma, WFlags flags );

private slots:
    void OnApply();
    void OnCancel();
    void OnActivate( QWidget *pPage ) ;

signals:
    void Apply ( int *Accept );
    void Cancel ( ) ;
    void Activate ( int ) ;

protected:
    void closeEvent ( QCloseEvent* );
    void accept () ;
    void Restart ( ) ;
 
    int         ApplyOK ;
    QWidget    *pInfo ;
    QWidget    *pDual ;
    QWidget    *pConfig ;
    QWidget    *pAdjust ;
    QWidget    *pTVout ;

};

// ### EOF ###
